using System; //Changed
using System.Windows.Forms;
using System.Drawing;

namespace Dbasic.EnhancedControls
{
	/// <summary>
	/// Summary description for CEnhancedButton.
	/// </summary>
    public class CEnhancedLabel : Control, IEnhancedControl, IText, IEnabled
    {
        public string name;
        public bool transparent = false;
        private System.Drawing.Rectangle destRect;
        private Brush bgdBrush;
        private Brush textBrush;
        private StringFormat stringFormat;
        private b4p b4p;
        public CEnhancedLabel(b4p b4p)
        {
            this.b4p = b4p;
            stringFormat = new StringFormat();
            destRect = new System.Drawing.Rectangle(0, 0, this.Width, this.Height);
            textBrush = new SolidBrush(this.ForeColor);
            bgdBrush = new SolidBrush(this.BackColor);
            this.Enabled = false;
            this.TabStop = false;
        }
        protected override void OnPaintBackground(PaintEventArgs pevent)
        {
        }
        protected override void OnPaint(PaintEventArgs e)
        {
            Graphics g = e.Graphics;
            destRect.Width = this.Width;
            destRect.Height = this.Height;
            if (!transparent)
            {
                g.FillRectangle(bgdBrush, destRect);
            }
            else
            {
                if (this.Parent is Panel)
                {
                    g.FillRectangle(new SolidBrush(this.Parent.BackColor)
                        , 0, 0, this.Width, this.Height);
                }
                else if (this.Parent is CEnhancedForm)
                {
                    CEnhancedForm frm = (CEnhancedForm)this.Parent;
                    g.DrawImage(
                        frm.bitmap,
                        new Rectangle(0, 0, this.Width, this.Height)
                        , new Rectangle((int)(this.Left / b4p.fixX)
                            , (int)(this.Top / b4p.fixY)
                            , (int)(this.Width / b4p.fixX)
                            , (int)(this.Height / b4p.fixY))
                        , GraphicsUnit.Pixel);
                }
            }
            g.DrawString(base.Text, this.Font, this.textBrush, destRect, stringFormat);
        }
        public override System.Drawing.Color ForeColor
        {
            get
            {
                return base.ForeColor;
            }
            set
            {
                textBrush = new SolidBrush(value);
                base.ForeColor = value;
            }
        }
        public override Color BackColor
        {
            get
            {
                return base.BackColor;
            }
            set
            {
                bgdBrush = new SolidBrush(value);
                base.BackColor = value;
            }
        }
        public bool Transparent
        {
            get { return transparent; }
            set { transparent = value; }
        }
        public override string Text
        {
            get
            {
                return base.Text;
            }
            set
            {
                base.Text = value;
                this.Refresh();
            }
        }

        public string propName
        {
            get
            {
                return name;
            }
        }
        public ContentAlignment TextAlign
        {
            set
            {
                switch (value)
                {
                    case ContentAlignment.TopLeft:
                        stringFormat.Alignment = StringAlignment.Near;
                        break;
                    case ContentAlignment.TopCenter:
                        stringFormat.Alignment = StringAlignment.Center;
                        break;
                    case ContentAlignment.TopRight:
                        stringFormat.Alignment = StringAlignment.Far;
                        break;
                }
                this.Refresh();
            }
        }
        void IEnhancedControl.AddRunTimeEvent(string eventName, string subName)
        {
        }
    }

}
